2025/01/27 Version 2.0.3
------------------------
- Fix closure bug in custom load/dump

2025/01/26 Version 2.0.2
------------------------
- Add `pyyaml` as a dependency

2025/01/23 Version 2.0.1
------------------------
- Fix `from_environment`

2025/01/23 Version 2.0.0
------------------------
- Must inherit from `BaseConfig`
- App name set by `@config` decorator
- `convert` field param replaced with `dump` and `load`
- Default local file is `~/.config/{app_name}.yaml` on MacOS

2025/01/23 Version 1.0.0
------------------------
- First draft
